==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/scf/v20180416/models/CfsConfig.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.scf.v20180416.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CfsConfig extends AbstractModel{

    /**
    * 文件系统信息列表
    */
    @SerializedName("CfsInsList")
    @Expose
    private CfsInsInfo [] CfsInsList;

    /**
     * Get 文件系统信息列表 
     * @return CfsInsList 文件系统信息列表
     */
    public CfsInsInfo [] getCfsInsList() {
        return this.CfsInsList;
    }

    /**
     * Set 文件系统信息列表
     * @param CfsInsList 文件系统信息列表
     */
    public void setCfsInsList(CfsInsInfo [] CfsInsList) {
        this.CfsInsList = CfsInsList;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "CfsInsList.", this.CfsInsList);

    }
}

==> tencentcloud-sdk-java-3.1.930-sources.jar: com/tencentcloudapi/scf/v20180416/models/CfsConfig.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.scf.v20180416.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CfsConfig extends AbstractModel {

    /**
    * 文件系统信息列表
    */
    @SerializedName("CfsInsList")
    @Expose
    private CfsInsInfo [] CfsInsList;

    /**
     * Get 文件系统信息列表 
     * @return CfsInsList 文件系统信息列表
     */
    public CfsInsInfo [] getCfsInsList() {
        return this.CfsInsList;
    }

    /**
     * Set 文件系统信息列表
     * @param CfsInsList 文件系统信息列表
     */
    public void setCfsInsList(CfsInsInfo [] CfsInsList) {
        this.CfsInsList = CfsInsList;
    }

    public CfsConfig() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public CfsConfig(CfsConfig source) {
        if (source.CfsInsList != null) {
            this.CfsInsList = new CfsInsInfo[source.CfsInsList.length];
            for (int i = 0; i < source.CfsInsList.length; i++) {
                this.CfsInsList[i] = new CfsInsInfo(source.CfsInsList[i]);
            }
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "CfsInsList.", this.CfsInsList);

    }
}
